# EvGoogleSearch
--------------

## Introduction
This plugin allows you to include a custom google search engine into your website. 
Why would you want to do that? In short, Google specializes in search engines so they are much better at it than we are and often clients specifically request for Google search so it makes sense for it to be a plugin.
> This plugin uses https://github.com/imarc/google-site-search and builds upon it for CakePHP / EvCore.

<br>
## Before Starting
Before we setup the plugin itself we require a few things, a Search Engine ID and an API key:

* Search Engine ID - On the [Custom Search Engine Control Panel](http://www.google.com/cse/manage/all), create a new search engine for the site you would like to integrate. Once created, you can retrieve your Search Engine ID from the Setup tab.

* API Key - If you're using the free option, visit the [Google Developers Console](https://console.developers.google.com/) and create a project for your search engine. Within your project, you’ll need to enable the Custom Search API from the APIs tab. Finally, on the Credentials tab, you will need to create a Public API access key by selecting the Create new Key option and choosing Server key. The API Key will now be available.

> Google's documentation for the Custom Search JSON API can be found here: https://developers.google.com/custom-search/json-api/v1/overview

<br>
## Installation

1. Install via composer using `composer require evoluted/googlesearch`
<br>
2. In your bootstrap.php file, either use `CakePlugin::loadAll()` or `CakePlugin::load('EvGoogleSearch, ['bootstrap' => true, 'config' => true]);`

<br>
## Usage

1. Firstly, create a file called `ev_google_search.php` inside your `App/Config` directory and copy / fill in your credentials:

~~~~
$config = array(
	'EvGoogleSearch' => array(
		'search_engine_id' => 'INSERT_ID_HERE',
		'api_key' => 'INSERT_API_KEY_HERE',
		'results_per_page' => 9
	)
);
~~~~
2. Assuming your credentials are correct and the URLS are configured via the Google Search Engine Control Panel itself, you should be able to access the functionality right out of the box via `/search/hello+world`
which should return a listing showing the google search results of "hello world".

3. All you need to do now, is create a form with an input name of `search_term` which submits via POST to /search

<br>
## Customisation
You may want to customise some features such as the results per page, routes, the listing or you may want to pass additional parameters to the Google Search API, here are your available options
<br>
* **Results per page**
This is nice and easy and is just a matter of changing the `results_per_page` key in the config file we set up earlier.
* **Routes**
If you want to change the URL of the search page (the listing itself) add this to your `routes.php` file:

~~~~
Router::connect(
	'/your-url-here/*',
	array(
		'plugin' => 'ev_google_search',
		'controller' => 'google_search',
		'action' => 'search'
	)
);
~~~~
* **Extending Functionality**
Most of the magic is in the `GoogleSearchComponent.php` file so if you want to add a search action to your own controller just add it to your $components array:

~~~~
public $components = array(
	'EvGoogleSearch.GoogleSearch'
);
~~~~
Then you will have access to the API methods and can perform the search by calling `$this->GoogleSearch->search($searchTerm, $currentPage)`. Check the Component/Controller for more info.

* **Searching specific urls within your site**

If you want to fetch results for a specific section of your website, for example /case-studies, you simply pass it into the search method under the key of `relatedSite`. Your call may look something like:

~~~~
$results = $this->GoogleSearch->search($searchTerm, $pageNumber, 9, array(
	'relatedSite' => '/case_studies',
));
~~~~
